@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2006 Sun Microsystems Inc.
+# Copyright 2006-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -14,16 +14,16 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 
 """Provides a graphical braille display at the top of the screen.
 This is mainly for debugging and for demonstrations."""
 
-__id__        = "$Id: brlmon.py 3076 2007-10-17 15:43:22Z richb $"
-__version__   = "$Revision: 3076 $"
-__date__      = "$Date: 2007-10-17 11:43:22 -0400 (Wed, 17 Oct 2007) $"
-__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__id__        = "$Id: brlmon.py 3882 2008-05-07 18:22:10Z richb $"
+__version__   = "$Revision: 3882 $"
+__date__      = "$Date: 2008-05-07 14:22:10 -0400 (Wed, 07 May 2008) $"
+__copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import gtk
@@ -95,11 +95,18 @@ class BrlMon(gtk.Window):
         self.set_property("accept-focus", False)
         self.connect_after("check-resize", self.onResize)
 
-    def onResize(self, object):
+    def onResize(self, obj):
         """Tell the window to be a dock and set its struts, which I
         thinks means to attempt to glue it somewhere on the display.
         """
 
+        # We know what we are doing here, so tell pylint not to flag
+        # the self.window method calls as errors (e.g., Class 'window' 
+        # has no 'get_size' member).  The disable-msg is localized to
+        # just this method.
+        #
+        # pylint: disable-msg=E1101
+
         screen_width = gtk.gdk.screen_width()
         [window_width, window_height] = self.window.get_size()
         if window_width < screen_width:
