@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2006 Sun Microsystems Inc.
+# Copyright 2006-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -14,15 +14,15 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 
 """Displays a GUI for the user to quit Orca."""
 
-__id__        = "$Id: orca_quit.py 3286 2007-11-29 21:29:08Z richb $"
-__version__   = "$Revision: 3286 $"
-__date__      = "$Date: 2007-11-29 16:29:08 -0500 (Thu, 29 Nov 2007) $"
-__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__id__        = "$Id: orca_quit.py 4025 2008-07-08 16:45:49Z richb $"
+__version__   = "$Revision: 4025 $"
+__date__      = "$Date: 2008-07-08 12:45:49 -0400 (Tue, 08 Jul 2008) $"
+__copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import os
@@ -58,7 +58,10 @@ class OrcaQuitGUI(orca_glade.GladeWrapper):
         #
         try:
             quitDialog.realize()
-            quitDialog.window.set_user_time(orca_state.lastInputEventTimestamp)
+            ts = orca_state.lastInputEventTimestamp
+            if ts == 0:
+                ts = gtk.get_current_event_time()
+            quitDialog.window.set_user_time(ts)
         except AttributeError:
             debug.printException(debug.LEVEL_FINEST)
 
