@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2007 Google Inc.
+# Copyright 2005-2008 Google Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -14,8 +14,8 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 #
 """Outloud voice definitions using ACSS.
 
@@ -25,13 +25,35 @@ Outloud voice parameter settings.
 
 """
 
-__id__ = "$Id: outloud.py 3082 2007-10-17 21:37:36Z richb $"
+__id__ = "$Id: outloud.py 4281 2008-10-08 22:05:56Z wwalker $"
 __author__ = "T. V. Raman"
-__version__ = "$Revision: 3082 $"
-__date__ = "$Date: 2007-10-17 17:37:36 -0400 (Wed, 17 Oct 2007) $"
-__copyright__ = "Copyright (c) 2005 Google Inc."
+__version__ = "$Revision: 4281 $"
+__date__ = "$Date: 2008-10-08 18:05:56 -0400 (Wed, 08 Oct 2008) $"
+__copyright__ = "Copyright (c) 2005-2008 Google Inc."
 __license__ = "LGPL"
 
+import chnames
+
+# Handling of special characters
+#
+# Emacspeak uses Tcl syntax to communicate with its speech servers.  It
+# embraces text in curly braces, so that at least {, }, and \ must be quoted
+# when sending text to speech server.  But individual speech engines have
+# their own special characters in addition to those of Tcl.  Outloud
+# perceives speech commands starting with backquote, and Emacspeak exploits
+# this to transmit speech settings to Outloud.  Thus we must quote `
+# (backquote) too.
+
+def makeSpecialCharMap():
+    """Returns list of pairs mapping characters which are special for
+    Outloud speech server to their replacements.
+    """
+    chars = r'{\}`'
+    return [(ch, ' '+chnames.getCharacterName(ch)+' ') for ch in chars]
+
+
+# Speech parameters
+
 _defined_voices = {}
 
 # Map from ACSS dimensions to Outloud settings:
@@ -105,11 +127,11 @@ _man_ap = [
     (9, 90, 20)
     ]
 
-_update_map(_table,('man', 'average-pitch'),
-            " `vb%s `vh% s",_man_ap)
+_update_map(_table, ('man', 'average-pitch'),
+            " `vb%s `vh% s", _man_ap)
 # same for Harry and dennis
-_update_map(_table,('harry', 'average-pitch'),
-            " `vb%s `vh% s",_man_ap)
+_update_map(_table, ('harry', 'average-pitch'),
+            " `vb%s `vh% s", _man_ap)
 _update_map(_table, ('dennis', 'average-pitch'),
             " `vb%s `vh%s ",  _male_ap)
 
@@ -355,9 +377,11 @@ _update_map(_table, ('child', 'richness'),
 # getrate is here for symmetry with other engines:
 # In the case of outloud, we dont need to normalize
 
-def getrate(r): return r
+def getrate(r):
+    return r
 
-def getvoicelist(): return _table['family'].keys()
+def getvoicelist():
+    return _table['family'].keys()
 
 def getvoice(acss):
     """Memoized function that returns  synthesizer code for
@@ -366,7 +390,8 @@ def getvoice(acss):
     where open sets the voice, and close resets it."""
 
     name = acss.name()
-    if name in _defined_voices: return _defined_voices[name]
+    if name in _defined_voices:
+        return _defined_voices[name]
     _defined_voices[name] = acss2voice(acss)
     return _defined_voices[name]
 
@@ -377,10 +402,13 @@ def acss2voice(acss):
     if 'family' in acss:
         familyName = acss['family']['name']
         code += _table['family'][familyName]
-    if 'rate' in acss: code += " `vs%s" % int(acss['rate'])
+    if 'rate' in acss:
+        code += " `vs%s" % int(acss['rate'])
     voice = ""
     for d in ['average-pitch', 'pitch-range',
               'richness', 'stress']:
-        if d in acss:voice += _table[(familyName, d)][int(acss[d])]
-    if code or voice: code = "%s %s" % (code, voice)
+        if d in acss:
+            voice += _table[(familyName, d)][int(acss[d])]
+    if code or voice:
+        code = "%s %s" % (code, voice)
     return (code, " `v1 ")
