@@ -31,9 +31,9 @@
 
 """Custom script for StarOffice and OpenOffice."""
 
-__id__        = "$Id: script.py 4167 2008-09-07 22:00:06Z joanied $"
-__version__   = "$Revision: 4167 $"
-__date__      = "$Date: 2008-09-07 18:00:06 -0400 (Sun, 07 Sep 2008) $"
+__id__        = "$Id: script.py 4294 2008-10-15 17:29:05Z joanied $"
+__version__   = "$Revision: 4294 $"
+__date__      = "$Date: 2008-10-15 13:29:05 -0400 (Wed, 15 Oct 2008) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -528,37 +528,15 @@ class Script(default.Script):
         Returns True if this is a table cell, False otherwise.
         """
 
-        found = False
-        rolesList = [pyatspi.ROLE_TABLE_CELL,
-                     pyatspi.ROLE_TABLE,
-                     [pyatspi.ROLE_UNKNOWN, pyatspi.ROLE_DOCUMENT_FRAME],
-                     pyatspi.ROLE_SCROLL_PANE,
-                     pyatspi.ROLE_PANEL,
-                     pyatspi.ROLE_ROOT_PANE,
-                     pyatspi.ROLE_FRAME,
-                     pyatspi.ROLE_APPLICATION]
-        if startFromTable:
-            rolesList = rolesList[1:]
-        if self.isDesiredFocusedItem(obj, rolesList):
-            # We've found a table cell with the correct hierarchy. Now check
-            # that we are in a spreadsheet as opposed to the writer application.
-            # See bug #382408.
-            #
-            current = obj.parent
-            while current.getRole() != pyatspi.ROLE_APPLICATION:
-                # Translators: this represents a match on a window title.
-                # We're looking for frame that ends in "Calc", representing
-                # an OpenOffice or StarOffice spreadsheet window.  We
-                # really try to avoid doing this kind of thing, but sometimes
-                # it is necessary and we apologize.
-                #
-                if current.getRole() in [pyatspi.ROLE_FRAME,
-                                         pyatspi.ROLE_ROOT_PANE] and \
-                   (current.name and current.name.endswith(_("Calc"))):
-                    found = True
-                current = current.parent
+        if not startFromTable:
+            obj = obj.parent
 
-        return found
+        try:
+            table = obj.queryTable()
+        except:
+            return False
+        else:
+            return table.nRows == 65536
 
     def isDesiredFocusedItem(self, obj, rolesList):
         """Called to determine if the given object and it's hierarchy of
@@ -1662,6 +1640,14 @@ class Script(default.Script):
             orca.setLocusOfFocus(event, event.source, True)
             return
 
+        # OOo Writer gets rather enthusiastic with focus: events for lists.
+        # See bug 546941.
+        #
+        if event.source.getRole() == pyatspi.ROLE_LIST \
+           and orca_state.locusOfFocus \
+           and self.isSameObject(orca_state.locusOfFocus.parent, event.source):
+            return
+
         default.Script.onFocus(self, event)
 
     def onActiveDescendantChanged(self, event):
